==> kubernetes-model-1.0.37-sources.jar: io/fabric8/kubernetes/api/model/ReplicationControllerStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class ReplicationControllerStatusBuilder extends ReplicationControllerStatusFluentImpl<ReplicationControllerStatusBuilder> implements VisitableBuilder<ReplicationControllerStatus,ReplicationControllerStatusBuilder>{

     ReplicationControllerStatusFluent<?> fluent;
public ReplicationControllerStatusBuilder(){
    this(new ReplicationControllerStatus());
}
public ReplicationControllerStatusBuilder( ReplicationControllerStatusFluent<?> fluent ){
    this(fluent, new ReplicationControllerStatus());
}
public ReplicationControllerStatusBuilder( ReplicationControllerStatusFluent<?> fluent , ReplicationControllerStatus instance ){
    this.fluent = fluent; fluent.withObservedGeneration(instance.getObservedGeneration()); fluent.withReplicas(instance.getReplicas()); 
}
public ReplicationControllerStatusBuilder( ReplicationControllerStatus instance ){
    this.fluent = this; this.withObservedGeneration(instance.getObservedGeneration()); this.withReplicas(instance.getReplicas()); 
}

public EditableReplicationControllerStatus build(){
    EditableReplicationControllerStatus buildable = new EditableReplicationControllerStatus(fluent.getObservedGeneration(),fluent.getReplicas());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ReplicationControllerStatusBuilder that = (ReplicationControllerStatusBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.46-sources.jar: io/fabric8/kubernetes/api/model/ReplicationControllerStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ReplicationControllerStatusBuilder extends ReplicationControllerStatusFluentImpl<ReplicationControllerStatusBuilder> implements VisitableBuilder<ReplicationControllerStatus,ReplicationControllerStatusBuilder>{

     ReplicationControllerStatusFluent<?> fluent;
public ReplicationControllerStatusBuilder(){
    this(new ReplicationControllerStatus());
}
public ReplicationControllerStatusBuilder( ReplicationControllerStatusFluent<?> fluent ){
    this(fluent, new ReplicationControllerStatus());
}
public ReplicationControllerStatusBuilder( ReplicationControllerStatusFluent<?> fluent , ReplicationControllerStatus instance ){
    this.fluent = fluent; fluent.withFullyLabeledReplicas(instance.getFullyLabeledReplicas()); fluent.withObservedGeneration(instance.getObservedGeneration()); fluent.withReplicas(instance.getReplicas()); 
}
public ReplicationControllerStatusBuilder( ReplicationControllerStatus instance ){
    this.fluent = this; this.withFullyLabeledReplicas(instance.getFullyLabeledReplicas()); this.withObservedGeneration(instance.getObservedGeneration()); this.withReplicas(instance.getReplicas()); 
}

public EditableReplicationControllerStatus build(){
    EditableReplicationControllerStatus buildable = new EditableReplicationControllerStatus(fluent.getFullyLabeledReplicas(),fluent.getObservedGeneration(),fluent.getReplicas());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ReplicationControllerStatusBuilder that = (ReplicationControllerStatusBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
